@@ -5,7 +5,7 @@ Functions for calculating geostrophic currents.
 import numpy as np
 
 from . import _gsw_ufuncs
-from ._utilities import match_args_return, indexer
+from ._utilities import indexer, match_args_return
 from .conversions import z_from_p
 
 __all__ = ['geo_strf_dyn_height',
@@ -50,16 +50,15 @@ def geo_strf_dyn_height(SA, CT, p, p_ref=0, axis=0, max_dp=1.0,
     """
     interp_methods = {'pchip' : 2, 'linear' : 1}
     if interp_method not in interp_methods:
-        raise ValueError('interp_method must be one of %s'
-                         % (interp_methods.keys(),))
+        raise ValueError(f'interp_method must be one of {interp_methods.keys()}')
     if SA.shape != CT.shape:
-        raise ValueError('Shapes of SA and CT must match; found %s and %s'
-                         % (SA.shape, CT.shape))
+        raise ValueError(f'Shapes of SA and CT must match; found {SA.shape} and {CT.shape}')
     if p.ndim == 1 and SA.ndim > 1:
         if len(p) != SA.shape[axis]:
-            raise ValueError('With 1-D p, len(p) must be SA.shape[axis];\n'
-                             ' found %d versus %d on specified axis, %d'
-                             % (len(p), SA.shape[axis], axis))
+            raise ValueError(
+                f'With 1-D p, len(p) must be SA.shape[axis];\n'
+                f' found {len(p)} versus {SA.shape[axis]} on specified axis, {axis}'
+                )
         ind = [np.newaxis] * SA.ndim
         ind[axis] = slice(None)
         p = p[tuple(ind)]
@@ -78,7 +77,8 @@ def geo_strf_dyn_height(SA, CT, p, p_ref=0, axis=0, max_dp=1.0,
     except AttributeError:
         order = 'C'  # e.g., xarray DataArray doesn't have flags
     for ind in indexer(SA.shape, axis, order=order):
-        igood = goodmask[ind]
+        # this is needed to support xarray inputs for numpy < 1.23
+        igood = np.asarray(goodmask[ind])
         # If p_ref is below the deepest value, skip the profile.
         pgood = p[ind][igood]
         if  len(pgood) > 1 and pgood[-1] >= p_ref:
@@ -176,12 +176,10 @@ def distance(lon, lat, p=0, axis=-1):
     earth_radius = 6371e3
 
     if not lon.shape == lat.shape:
-        raise ValueError('lon, lat shapes must match; found %s, %s'
-                          % (lon.shape, lat.shape))
+        raise ValueError(f'lon, lat shapes must match; found {lon.shape}, {lat.shape}')
     if not (lon.ndim in (1, 2) and lon.shape[axis] > 1):
         raise ValueError('lon, lat must be 1-D or 2-D with more than one point'
-                         ' along axis; found shape %s and axis %s'
-                          % (lon.shape, axis))
+                         ' along axis; found shape {} and axis {}'.format(lon.shape, axis))
     if lon.ndim == 1:
         one_d = True
         # xarray requires expand_dims() rather than [newaxis, :]
@@ -293,12 +291,10 @@ def geostrophic_velocity(geo_strf, lon, lat, p=0, axis=0):
     lon = unwrap(lon)
 
     if lon.shape != lat.shape or lon.ndim != 1:
-        raise ValueError('lon, lat must be 1-D and matching; found shapes'
-                         ' %s and %s' % (lon.shape, lat.shape))
+        raise ValueError(f'lon, lat must be 1-D and matching; found shapes {lon.shape} and {lat.shape}')
 
     if geo_strf.ndim not in (1, 2):
-        raise ValueError('geo_strf must be 1-D or 2-d; found shape %s'
-                         % (geo_strf.shape,))
+        raise ValueError(f'geo_strf must be 1-D or 2-d; found shape {geo_strf.shape}')
 
     laxis = 0 if axis else -1
 
